package com.ruoyi.web.modules.trading.service;

import java.util.List;
import com.ruoyi.web.modules.trading.domain.BizDistributor;

/**
 * 承销商服务
 */
public interface IBizDistributorService
{
    BizDistributor selectBizDistributorById(Long id);

    List<BizDistributor> selectBizDistributorList(BizDistributor query);

    int insertBizDistributor(BizDistributor row);

    int updateBizDistributor(BizDistributor row);

    int deleteBizDistributorByIds(Long[] ids, String updateBy);

    int assignAccount(Long id, String operator);
}
